@@ -1,7 +1,7 @@
 
 #   IGraph R package
-#   Copyright (C) 2005  Gabor Csardi <csardi@rmki.kfki.hu>
-#   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+#   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
+#   334 Harvard street, Cambridge, MA 02139 USA
 #   
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,10 +28,10 @@
 power.law.fit <- function(x, xmin=NULL, start=2, ...) {
 
   if (length(x) == 0) {
-    error("zero length vector")
+    stop("zero length vector")
   }
   if (length(x) == 1) {
-    error("vector should be at least of length two")
+    stop("vector should be at least of length two")
   }  
 
   require(stats4)
