@@ -1,7 +1,7 @@
 
 #   IGraph R package
-#   Copyright (C) 2003, 2004, 2005  Gabor Csardi <csardi@rmki.kfki.hu>
-#   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+#   Copyright (C) 2003-2012  Gabor Csardi <csardi.gabor@gmail.com>
+#   334 Harvard street, Cambridge, MA 02139 USA
 #   
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ i.parse.plot.params <- function(graph, params) {
       } else {
         ## no attributes either, check igraph parameters
         n <- paste(sep="", type, ".", name)
-        v <- igraph.par(n)
+        v <- getIgraphOpt(n)
         if (!is.null(v)) {
           p[[type]][[name]] <- v
           return(ret())
@@ -110,88 +110,6 @@ i.parse.plot.params <- function(graph, params) {
   return (func)
 }
 
-i.get.layout <- function(graph, layout, layout.par) {
-
-  if (is.function(layout)) {
-    layout <- layout(graph, layout.par)
-  } else if (is.character(layout) && length(layout)==1 &&
-             substr(layout, 1, 2)=="a:") {
-    layout <- matrix(unlist(get.vertex.attribute(graph, substring(layout,3))),
-                     nr=vcount(graph), byrow=TRUE)[,1:2]
-  }  
-
-  layout
-}
-
-i.get.vertex.color <- function(graph, vertex.color) {
-
-  if (length(vertex.color)==1 && substr(vertex.color, 1, 2)=="a:") {
-    vertex.color <- unlist(get.vertex.attribute(graph,
-                                                substring(vertex.color,3)))
-  }
-
-  if (is.numeric(vertex.color)) {
-    vertex.color <- vertex.color %% length(palette())
-    vertex.color[vertex.color==0] <- length(palette())
-    vertex.color <- palette()[vertex.color]
-  }
-
-  vertex.color  
-}
-
-i.get.vertex.frame.color <- function(graph, vertex.frame.color) {
-
-  if (length(vertex.frame.color)==1 &&
-      substr(vertex.frame.color, 1, 2)=="a:") {
-    vertex.frame.color <-
-      unlist(get.vertex.attribute(graph,
-                                  substring(vertex.frame.color,3)))
-  }
-
-  if (is.numeric(vertex.frame.color)) {
-    vertex.frame.color <- vertex.frame.color %% length(palette())
-    vertex.frame.color[vertex.frame.color==0] <- length(palette())
-    vertex.frame.color <- palette()[vertex.frame.color]
-  }
-
-  vertex.frame.color  
-}
-
-i.get.vertex.size <- function(graph, vertex.size) {
-
-  if (is.character(vertex.size) &&
-      length(vertex.size)==1 && substr(vertex.size, 1, 2)=="a:") {
-    vertex.size <- as.numeric(get.vertex.attribute
-                                 (graph, substring(vertex.size,3)))
-  }
-  vertex.size
-}
-
-i.get.edge.color <- function(graph, edge.color) {
-
-  if (length(edge.color)==1 && substr(edge.color, 1, 2)=="a:") {
-    edge.color <- as.character(get.edge.attribute
-                               (graph, substring(edge.color,3)))
-  }
-
-  if (is.numeric(edge.color)) {
-    edge.color <- edge.color %% length(palette())
-    edge.color[edge.color==0] <- length(palette())
-    edge.color <- palette()[edge.color]
-  }
-  edge.color
-}
-
-i.get.edge.width <- function(graph, edge.width) {
-
-  if (is.character(edge.width) &&
-      length(edge.width)==1 && substr(edge.width, 1, 2)=="a:") {
-    edge.width <- as.character(get.edge.attribute
-                               (graph, substring(edge.width,3)))
-  }
-  edge.width
-}
-
 i.get.edge.labels <- function(graph, edge.labels=NULL) {
 
   if (is.null(edge.labels)) {
@@ -201,20 +119,10 @@ i.get.edge.labels <- function(graph, edge.labels=NULL) {
   edge.labels
 }
 
-i.get.label.degree <- function(graph, label.degree) {
-
-  if (is.character(label.degree) &&
-      length(label.degree)==1 && substr(label.degree, 1, 2)=="a:") {
-    label.degree <- as.numeric(get.vertex.attribute
-                               (graph, substring(label.degree,3)))
-  }
-  label.degree
-}
-
 i.get.labels <- function(graph, labels=NULL) {
 
   if (is.null(labels)) {
-    labels <- 0:(vcount(graph)-1)
+    labels <- seq_len(vcount(graph))
   }
   labels
 }
@@ -255,6 +163,28 @@ igraph.check.shapes <- function(x) {
   x
 }
 
+autocurve.edges <- function(graph, start=0.5) {
+  cm <- count.multiple(graph)
+  el <- apply(get.edgelist(graph, names=FALSE), 1, paste, collapse=":")
+  ord <- order(el)
+  res <- numeric(length(ord))
+
+  p <- 1
+  while (p <= length(res)) {
+    m <- cm[ord[p]]
+    idx <- p:(p+m-1)
+    if (m==1) {
+      r <- 0
+    } else {
+      r <- seq(-start, start, length=m)
+    }
+    res[ord[idx]] <- r
+    p <- p + m
+  }
+
+  res
+}
+
 i.default.values <- list(vertex=list(color="SkyBlue2",
                            size=15,
                            size2=15,
@@ -266,7 +196,15 @@ i.default.values <- list(vertex=list(color="SkyBlue2",
                            label.font=1,
                            label.cex=1,
                            frame.color="black",
-                           shape="circle"),
+                           shape="circle",
+                           pie=1,
+                           pie.color=list(c("white", "lightblue", "mistyrose",
+                             "lightcyan", "lavender", "cornsilk")),
+                           pie.border=list(c("white", "lightblue","mistyrose",
+                             "lightcyan", "lavender", "cornsilk")),
+                           pie.angle=45,
+                           pie.density=-1,
+                           pie.lty=1),
                          edge=list(color="darkgrey",
                            label=i.get.edge.labels,
                            lty=1,
@@ -279,9 +217,9 @@ i.default.values <- list(vertex=list(color="SkyBlue2",
                            label.color="darkblue",
                            arrow.size=1,
                            arrow.mode=i.get.arrow.mode,
-                           curved=FALSE,
+                           curved=autocurve.edges,
                            arrow.width=1),
-                         plot=list(layout=layout.random,
+                         plot=list(layout=layout.auto,
                            margin=c(0,0,0,0),
                            rescale=TRUE,
                            asp=1,
