@@ -17,11 +17,13 @@ Copyright (C) 2003-2006 Tommi Junttila
 
 /* FSF address fixed in the above notice on 1 Oct 2009 by Tamas Nepusz */
 
-#include <stdlib.h>
-#include <assert.h>
+#include <cstdlib>
+#include <cassert>
 #include "bliss_defs.hh"
 #include "bliss_orbit.hh"
 
+using namespace std;
+
 namespace igraph {
 
 Orbit::Orbit()
