@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2007  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2007-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard street, Cambridge, MA 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -61,7 +61,10 @@
 #include <iostream>
 #include <fstream>
 
-#include "igraph.h"
+#include "igraph_community.h"
+#include "igraph_components.h"
+#include "igraph_interface.h"
+#include "igraph_interrupt_internal.h"
 
 using namespace std;
 
@@ -83,7 +86,7 @@ using namespace std;
  * Note that the graph must not contain isolated vertices in order to
  * use this method.
  *
- * \param graph The input graph.
+ * \param graph The input graph, edge directions are ignored.
  * \param weights Numeric vector giving the weights of the edges. 
  *     If it is a NULL pointer then all edges will have equal
  *     weights. The weights are expected to be positive.
@@ -91,17 +94,21 @@ using namespace std;
  * \param merges Pointer to a matrix, the merges performed by the
  *     algorithm will be stored here (if not NULL). Each merge is a
  *     row in a two-column matrix and contains the ids of the merged
- *     clusters. Clusters are numbered from zero and cluster number 
+ *     clusters. Clusters are numbered from zero and cluster numbers 
  *     smaller than the number of nodes in the network belong to the
  *     individual vertices as singleton clusters. In each step a new
  *     cluster is created from two other clusters and its id will be 
  *     one larger than the largest cluster id so far. This means that 
  *     before the first merge we have \c n clusters (the number of
  *     vertices in the graph) numbered from zero to \c n-1. The first
- *     merge created cluster \c n, the second cluster \c n+1, etc.
+ *     merge creates cluster \c n, the second cluster \c n+1, etc.
  * \param modularity Pointer to a vector. If not NULL then the
  *     modularity score of the current clustering is stored here after
  *     each merge operation. 
+ * \param membership Pointer to a vector. If not a NULL pointer, then
+ *     the membership vector corresponding to the maximal modularity
+ *     score is stored here. If it is not a NULL pointer, then \p
+ *     modularity must not be a NULL pointer, either.
  * \return Error code.
  * 
  * \sa \ref igraph_community_spinglass(), \ref
@@ -109,24 +116,35 @@ using namespace std;
  * 
  * Time complexity: O(|E||V|^2) in the worst case, O(|V|^2 log|V|) typically, 
  * |V| is the number of vertices, |E| is the number of edges.
+ * 
+ * \example examples/simple/walktrap.c
  */
 
 int igraph_community_walktrap(const igraph_t *graph, 
 			      const igraph_vector_t *weights,
 			      int steps,
 			      igraph_matrix_t *merges,
-			      igraph_vector_t *modularity) {
+			      igraph_vector_t *modularity, 
+			      igraph_vector_t *membership) {
 
   long int no_of_nodes=(long int)igraph_vcount(graph);
   int length=steps;
   long max_memory=-1;
-  
+
+  if (membership && !modularity) {
+    IGRAPH_ERROR("Cannot calculate membership without modularity",
+		 IGRAPH_EINVAL);
+  }
+
   Graph* G = new Graph;
   if (G->convert_from_igraph(graph, weights))
       IGRAPH_ERROR("isolated vertex found in graph", IGRAPH_EINVAL);
   
   if (merges) {
-    IGRAPH_CHECK(igraph_matrix_resize(merges, no_of_nodes-1, 2));
+    igraph_integer_t no;
+    IGRAPH_CHECK(igraph_clusters(graph, /*membership=*/ 0, /*csize=*/ 0, 
+				 &no, IGRAPH_WEAK));
+    IGRAPH_CHECK(igraph_matrix_resize(merges, no_of_nodes-no, 2));
   }
   if (modularity) {
     IGRAPH_CHECK(igraph_vector_resize(modularity, no_of_nodes));
@@ -140,6 +158,14 @@ int igraph_community_walktrap(const igraph_t *graph,
   }
   
   delete G;
+
+  if (membership && modularity) {
+    long int m=igraph_vector_which_max(modularity);
+    IGRAPH_CHECK(igraph_community_to_membership(merges, no_of_nodes, 
+						/*steps=*/ m,
+						membership, 
+						/*csize=*/ 0));
+  }
   
   return 0;
 }
